#include <simpletools.h>            
#include <propeller.h>
#include <stdbool.h>
#include <stdio.h>
#include <cog.h>

/*.................................................................
Start 1Hz PASM (Pulse1Hz.Spin) PUB PULSE

//.................................................................*/
int startPulse1Hz(unsigned int * par){
  extern unsigned int *binary_Pulse1Hz_dat_start;  
  return cognew(&binary_Pulse1Hz_dat_start,0);
}

int main()                                    // Main function
{

const int PosDetMask =        0b100000000000000000000000000000; // Positive edge detection mode
const int NegDetMask =        0b110000000000000000000000000000; // Negative edge detection mode
const int IpBitMaskPendulum = 0b000000000000100000000000000000; // Mask for INA Register Pin Location 
long   Pendulum = 17;                          // Select Input pin

/*
Design note write code to generate "IpBitMaskPendulum"
*/

unsigned long  hightime = 0;
unsigned long  Tick = 0; 
unsigned long  Tock = 0;

bool  TickFlag = true;
bool  CountStabalised = true;
bool  DataReady = false;


startPulse1Hz(0);

  set_direction(Pendulum,0);                     // enable pin for input
  waitcnt(CLKFREQ/10 + CNT);

  printf("Clock Frequency %d \n\n",CLKFREQ); 

  CTRA = PosDetMask + Pendulum;                  // POSDET Set control mode and Pin
  FRQA = 1;

  CTRB = NegDetMask + Pendulum;                  // NEGDET  "     "      "   "    "
  FRQB = 1;

  waitpeq(IpBitMaskPendulum, IpBitMaskPendulum); //sync to input
  waitpeq(0,  IpBitMaskPendulum);
  PHSA = 0;                                      // ready for POSDET phase
  waitpne( IpBitMaskPendulum,  IpBitMaskPendulum);

  printf("Ready for positive detect %d\n");   

  while(1)  {

    PHSB = 0;                               // pin is high, POSDET phsa advancing, phsb not
    waitpeq(0 ,  IpBitMaskPendulum);        // pin goes low, phsa stops, phsb starts
    hightime = PHSA;                        // pin is low, NEGDET phsb advancing, phsa not 
    PHSA = 0;                              
                                 
    waitpeq( IpBitMaskPendulum,  IpBitMaskPendulum);          // pin goes high, phsb stops, phsa starts
    if(TickFlag)  {
        Tick = PHSB + hightime; //
        TickFlag = false; 
        printf("Tick %d  " , Tick); 
      }                                            
    else  {
      Tock = PHSB + hightime;
      TickFlag = true;
      printf(":: Tock %d" , Tock);
      printf(" :: Beat Error %d \n" ,Tick - Tock);      
      if (CountStabalised > 2) {
        DataReady = true; // New Data ready for reading
      }                                           
      else  {  
          CountStabalised++; 
      }// if Count stabilised           
    }// if Tickflag 
 } // while
print("Done \n");
}

